@@ -30,10 +30,10 @@ using System;
 using Mono.Unix;
 using Gtk;
 
+using Hyena;
 using Hyena.Jobs;
 using Hyena.Gui;
 
-using Banshee.Base;
 using Banshee.ServiceStack;
 
 namespace Banshee.Gui.Widgets
@@ -56,7 +56,7 @@ namespace Banshee.Gui.Widgets
         private uint progress_bounce_id;
         private object tooltips;
 
-        Banshee.Widgets.HigMessageDialog cancel_dialog;
+        Hyena.Widgets.HigMessageDialog cancel_dialog;
 
         public UserJobTile (Job job) : base (3, 2, false)
         {
@@ -132,7 +132,7 @@ namespace Banshee.Gui.Widgets
                 parent = ServiceManager.Get<GtkElementsService> ().PrimaryWindow;
             }
 
-            cancel_dialog = new Banshee.Widgets.HigMessageDialog (parent,
+            cancel_dialog = new Hyena.Widgets.HigMessageDialog (parent,
                 DialogFlags.Modal, MessageType.Question, ButtonsType.None,
                 job.Title == null
                     ? Catalog.GetString ("Stop Operation")
@@ -256,7 +256,10 @@ namespace Banshee.Gui.Widgets
                 return;
             }
 
-            icon_pixbuf = new Gdk.Pixbuf (icon_names[0]);
+            try {
+                icon_pixbuf = new Gdk.Pixbuf (icon_names[0]);
+            } catch (GLib.GException) {}
+
             if (icon_pixbuf != null) {
                 Gdk.Pixbuf scaled = icon_pixbuf.ScaleSimple (22, 22, Gdk.InterpType.Bilinear);
                 icon_pixbuf.Dispose ();
